==> glib-web-0.5.86.tgz: package/components/mixins/table/autoload.js <==
export default {
  data: function() {
    return {
      topScrollHandler: null,
      bottomScrollHandler: null,
      nextPageUrl: null,
      prevPageUrl: null,
      request: null,
      infiniteScroll: null
    };
  },
  computed: {
    bottomAnchorStyles() {
      return {
        display: this.infiniteScroll && this.nextPageUrl ? "block" : "none"
      };
    }
  },
  methods: {
    enableInfiniteScrollIfApplicable: function() {
      this.$removeViewportChangeListeners(this.topScrollHandler);
      this.$removeViewportChangeListeners(this.bottomScrollHandler);

      const prevPage = this.spec.prevPage || {};
      const nextPage = this.spec.nextPage || {};

      this.infiniteScroll = nextPage.autoload == "asNeeded";
      const onScrollToBottom = this.spec.onScrollToBottom;
      const onScrollToTop = this.spec.onScrollToTop;

      if (this.infiniteScroll) {
        this.nextPageUrl = nextPage.url;
        this.prevPageUrl = prevPage.url;
      }

      if (this.nextPageUrl || onScrollToBottom) {
        this._registerBottomScroll(onScrollToBottom);
      }

      if (this.prevPageUrl || onScrollToTop) {
        this._registerTopScroll(onScrollToTop);
      }
    },
    _registerTopScroll(onScrollToTop) {
      // TODO: Consider adding support for prevPageUrl
      this.topScrollHandler = this.$onVisibilityChange(
        this.$refs.topAnchor,
        (el, visible) => {
          if (visible) {
            this._handleTopScroll(onScrollToTop);
          }
        }
      );

      this.$addViewportChangeListeners(this.topScrollHandler);
      // this.topScrollHandler();
    },
    _handleTopScroll(onScrollToTop) {
      GLib.action.execute(onScrollToTop, null, this);
    },
    _registerBottomScroll(onScrollToBottom) {
      this.bottomScrollHandler = this.$onVisibilityChange(
        this.$refs.bottomAnchor,
        (el, visible) => {
          if (visible) {
            this._handleBottomScroll(onScrollToBottom);
          }
        }
      );

      this.$addViewportChangeListeners(this.bottomScrollHandler);
      // NOTE: Right now there is an issue where after popping to previus page, the page auto-loads from the beginning
      // again, so we get duplicate rows.
      // this.bottomScrollHandler();
    },
    _handleBottomScroll(onScrollToBottom) {
      if (this.nextPageUrl) {
        this.request = Utils.http.execute(
          { url: this.nextPageUrl },
          "GET",
          this,
          response => {
            const nextPage = response.nextPage;
            if (this.$type.isObject(nextPage)) {
              this.nextPageUrl = response.nextPage.url;
            } else {
              this.nextPageUrl = null;
            }

            for (const section of response.sections) {
              this.sections.push(section);
            }
            Utils.history.updatePage();
          }
        );
      }

      GLib.action.execute(onScrollToBottom, null, this);
    },
    autoloadAll(nextPage) {
      const vm = this;

      if (!this.$type.isObject(nextPage)) {
        return;
      }
      if (nextPage.autoload !== "all") {
        return;
      }

      let nextPageUrl = nextPage.url;

      this.request = Utils.http.execute(
        { url: nextPageUrl },
        "GET",
        vm,
        function(response) {
          for (const section of response.sections) {
            vm.sections.push(section);
          }
          vm.autoloadAll(response.nextPage);
        }
      );
    },
    cancelAutoloadRequest() {
      // Avoid old data coming in when this component gets reused.
      if (this.request) {
        this.request.cancel();
      }
    }
  }
};

==> glib-web-2.6.3.tgz: package/components/mixins/table/autoload.js <==
export default {
  data: function() {
    return {
      topScrollHandler: null,
      bottomScrollHandler: null,
      nextPageUrl: null,
      prevPageUrl: null,
      request: null,
      infiniteScroll: null
    };
  },
  computed: {
    bottomAnchorStyles() {
      return {
        display: this.infiniteScroll && this.nextPageUrl ? "block" : "none"
      };
    }
  },
  methods: {
    enableInfiniteScrollIfApplicable: function() {
      this.$removeViewportChangeListeners(this.topScrollHandler);
      this.$removeViewportChangeListeners(this.bottomScrollHandler);

      const prevPage = this.spec.prevPage || {};
      const nextPage = this.spec.nextPage || {};

      this.infiniteScroll = nextPage.autoload == "asNeeded";
      const onScrollToBottom = this.spec.onScrollToBottom;
      const onScrollToTop = this.spec.onScrollToTop;

      if (this.infiniteScroll) {
        this.nextPageUrl = nextPage.url;
        this.prevPageUrl = prevPage.url;
      }

      if (this.nextPageUrl || onScrollToBottom) {
        this._registerBottomScroll(onScrollToBottom);
      }

      if (this.prevPageUrl || onScrollToTop) {
        this._registerTopScroll(onScrollToTop);
      }
    },
    _registerTopScroll(onScrollToTop) {
      // TODO: Consider adding support for prevPageUrl
      this.topScrollHandler = this.$onVisibilityChange(
        this.$refs.topAnchor,
        (el, visible) => {
          if (visible) {
            this._handleTopScroll(onScrollToTop);
          }
        }
      );

      this.$addViewportChangeListeners(this.topScrollHandler);
      // this.topScrollHandler();
    },
    _handleTopScroll(onScrollToTop) {
      GLib.action.execute(onScrollToTop, this);
    },
    _registerBottomScroll(onScrollToBottom) {
      this.bottomScrollHandler = this.$onVisibilityChange(
        this.$refs.bottomAnchor,
        (el, visible) => {
          if (visible) {
            this._handleBottomScroll(onScrollToBottom);
          }
        }
      );

      this.$addViewportChangeListeners(this.bottomScrollHandler);
      // NOTE: Right now there is an issue where after popping to previus page, the page auto-loads from the beginning
      // again, so we get duplicate rows.
      // this.bottomScrollHandler();
    },
    _handleBottomScroll(onScrollToBottom) {
      if (this.nextPageUrl) {
        this.request = Utils.http.execute(
          { url: this.nextPageUrl },
          "GET",
          this,
          response => {
            const nextPage = response.nextPage;
            if (this.$type.isObject(nextPage)) {
              this.nextPageUrl = response.nextPage.url;
            } else {
              this.nextPageUrl = null;
            }

            for (const section of response.sections) {
              this.sections.push(section);
            }
            Utils.history.updatePage();
          }
        );
      }

      GLib.action.execute(onScrollToBottom, this);
    },
    autoloadAll(nextPage) {
      const vm = this;

      if (!this.$type.isObject(nextPage)) {
        return;
      }
      if (nextPage.autoload !== "all") {
        return;
      }

      let nextPageUrl = nextPage.url;

      this.request = Utils.http.execute(
        { url: nextPageUrl },
        "GET",
        vm,
        function(response) {
          for (const section of response.sections) {
            vm.sections.push(section);
          }
          vm.autoloadAll(response.nextPage);
        }
      );
    },
    cancelAutoloadRequest() {
      // Avoid old data coming in when this component gets reused.
      if (this.request) {
        this.request.cancel();
      }
    }
  }
};
